==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/form-view/useDeleteDefinitionField.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/form-view/useDeleteDefinitionField.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-renderer/js/util/visitors.es', 'frontend-js-react-web$react', '../../utils/dataLayoutVisitor.es', './FormViewContext.es', './actions.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _visitors = require("dynamic-data-mapping-form-renderer/js/util/visitors.es");

  var _react = require("frontend-js-react-web$react");

  var _dataLayoutVisitor = require("../../utils/dataLayoutVisitor.es");

  var _FormViewContext = _interopRequireDefault(require("./FormViewContext.es"));

  var _actions = require("./actions.es");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(_ref) {
    var dataLayoutBuilder = _ref.dataLayoutBuilder;

    var _useContext = (0, _react.useContext)(_FormViewContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        dataLayout = _useContext2[0].dataLayout,
        dispatch = _useContext2[1];

    return function (fieldName) {
      var _dataLayoutBuilder$ge = dataLayoutBuilder.getStore(),
          pages = _dataLayoutBuilder$ge.pages;

      var visitor = new _visitors.PagesVisitor(pages);

      if (visitor.containsField(fieldName)) {
        var indexes = (0, _dataLayoutVisitor.getIndexesFromFieldName)(dataLayout, fieldName);
        dataLayoutBuilder.dispatch('fieldDeleted', {
          indexes: indexes
        });
      } else {
        dispatch((0, _actions.deleteDefinitionField)(fieldName));
      }
    };
  };

  exports["default"] = _default;
  //# sourceMappingURL=useDeleteDefinitionField.es.js.map
});
//# sourceMappingURL=useDeleteDefinitionField.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/form-view/useDeleteDefinitionField.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/form-view/useDeleteDefinitionField.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-renderer', 'frontend-js-react-web$react', './FormViewContext.es', './actions.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dynamicDataMappingFormRenderer = require("dynamic-data-mapping-form-renderer");

  var _react = require("frontend-js-react-web$react");

  var _FormViewContext = _interopRequireDefault(require("./FormViewContext.es"));

  var _actions = require("./actions.es");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(_ref) {
    var dataLayoutBuilder = _ref.dataLayoutBuilder;

    var _useContext = (0, _react.useContext)(_FormViewContext["default"]),
        _useContext2 = _slicedToArray(_useContext, 2),
        dispatch = _useContext2[1];

    return function (fieldName) {
      var _dataLayoutBuilder$ge = dataLayoutBuilder.getStore(),
          pages = _dataLayoutBuilder$ge.pages;

      var visitor = new _dynamicDataMappingFormRenderer.PagesVisitor(pages);

      if (visitor.containsField(fieldName, true)) {
        dataLayoutBuilder.dispatch('fieldDeleted', {
          fieldName: fieldName
        });
      } else {
        dispatch((0, _actions.deleteDefinitionField)(fieldName));
      }
    };
  };

  exports["default"] = _default;
  //# sourceMappingURL=useDeleteDefinitionField.es.js.map
});
//# sourceMappingURL=useDeleteDefinitionField.es.js.map
